@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::UploadToCPAN::WWWPAUSESimple;
 
-our $DATE = '2016-07-13'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2017-01-12'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use Moose;
 with qw(Dist::Zilla::Role::BeforeRelease Dist::Zilla::Role::Releaser);
@@ -138,8 +138,8 @@ sub release {
   #print "D: username: ", $self->username, "\n";
   #print "D: password: ", $self->password, "\n";
 
-  $self->log(["Uploading %s to CPAN ...", $archive]);
-  my $res = WWW::PAUSE::Simple::upload_file(
+  $self->log(["Uploading %s to CPAN ...", "$archive"]);
+  my $res = WWW::PAUSE::Simple::upload_files(
       username    => $self->username,
       password    => $self->password,
       subdir      => $self->subdir,
@@ -147,7 +147,11 @@ sub release {
       retries     => $self->retries,
       retry_delay => $self->retry_delay,
   );
-  $self->log_fatal(["Upload failed: %s", $res]) unless $res->[0] == 200;
+  if ($res->[0] == 200) {
+      $self->log(["Upload succeeded: %s", $res]);
+  } else {
+      $self->log_fatal(["Upload failed: %s", $res]);
+  }
 
 }
 
@@ -167,7 +171,7 @@ Dist::Zilla::Plugin::UploadToCPAN::WWWPAUSESimple - Upload the dist to CPAN (usi
 
 =head1 VERSION
 
-This document describes version 0.03 of Dist::Zilla::Plugin::UploadToCPAN::WWWPAUSESimple (from Perl distribution Dist-Zilla-Plugin-UploadToCPAN-WWWPAUSESimple), released on 2016-07-13.
+This document describes version 0.04 of Dist::Zilla::Plugin::UploadToCPAN::WWWPAUSESimple (from Perl distribution Dist-Zilla-Plugin-UploadToCPAN-WWWPAUSESimple), released on 2017-01-12.
 
 =head1 SYNOPSIS
 
@@ -216,7 +220,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
